# OpenTSDBClient
A simple OpenTSDB client for Python 3.11+. 

**Warning:** This is a work in progress and not ready for production use yet.
Breaking changes will be introduced at a regular basis. Feel free to partiscipate in the development by issues or pull requests.
